RevaliClient class
Constructors
- RevaliClient({required Storage storage, HttpClient? client, String? baseUrl, Duration? timeout, RetryPolicy retry = const RetryPolicy.none()})
Properties
- baseUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interceptors
→ List<
HttpInterceptor> -
no setter
- retry → RetryPolicy
-
When a failed request is sent again. Off by default.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storage → Storage
-
final
- timeout → Duration?
-
How long to wait for a response before giving up.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
request(
{required String method, required String path, Map< String, dynamic> ? headers, Object? body, Map<String, dynamic> query = const {}}) → Future<HttpResponse> -
headersAccepts either a Map<String, List -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited